@@ -132,8 +132,41 @@ class LoadTradeKline:
                         'price': trade['price'],
                         'amount': trade['amount'],
                     })
-                self.table.upsert(result)
+                self.table.insert(result)
                 time.sleep(int(self.exchange.rateLimit / 1000))
             except ccxt.NetworkError as e:
                 print(type(e).__name__, str(e))
                 self.exchange.sleep(10000)
+
+    def load_csv(self, symbol, unix_start, unix_end, *args, **kwargs):
+        one_hour = 3600 * 1000
+        since = unix_start
+        previous_trade_id = None
+        result = []
+        while since < unix_end:
+            try:
+                trades = self.exchange.fetch_trades(symbol, since, limit=1000)
+                if len(trades) == 0:
+                    since += one_hour
+                    continue
+                last_trade = trades[-1]
+                if previous_trade_id == last_trade['id']:
+                    since += one_hour
+                    continue
+                since = last_trade['timestamp']
+                previous_trade_id = last_trade['id']
+                result.extend([{
+                    'symbol': trade['symbol'],
+                    'id': trade['id'],
+                    'timestamp': trade['timestamp'],
+                    'type': trade['type'],
+                    'side': trade['side'],
+                    'price': trade['price'],
+                    'amount': trade['amount'],
+                } for trade in trades])
+
+                time.sleep(int(self.exchange.rateLimit / 1000))
+            except ccxt.NetworkError as e:
+                print(type(e).__name__, str(e))
+                self.exchange.sleep(10000)
+        self.table.insert(result)
